.. include global.rst

Jedi - an awesome autocompletion/static analysis library for Python
===================================================================

Release v\ |release|. (:doc:`Installation <docs/installation>`)

.. automodule:: jedi

Autocompletion can look like this (e.g. VIM plugin):

.. figure:: _screenshots/screenshot_complete.png


.. _toc:

Docs
----

.. toctree::
   :maxdepth: 2

   docs/usage
   docs/installation
   docs/features
   docs/api
   docs/api-classes
   docs/settings
   docs/development
   docs/testing


.. _resources:

Resources
---------

- `Source Code on Github <https://github.com/davidhalter/jedi>`_
- `Travis Testing <https://travis-ci.org/davidhalter/jedi>`_
- `Python Package Index <https://pypi.python.org/pypi/jedi/>`_
